==> ask_sdk_model-1.6.1-py2.py3-none-any.whl: ask_sdk_model/services/game_engine/pattern_recognizer_anchor_type.py <==
# coding: utf-8

#
# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional
    from datetime import datetime


class PatternRecognizerAnchorType(Enum):
    """
    Where the pattern must appear in the history of this input handler. * &#x60;start&#x60; -  (Default) The first event in the pattern must be the first event in the history of raw Echo Button events. * &#x60;end&#x60; - The last event in the pattern must be the last event in the history of raw Echo Button events. * &#x60;anywhere&#x60; - The pattern may appear anywhere in the history of raw Echo Button events. 



    Allowed enum values: [start, end, anywhere]
    """
    start = "start"
    end = "end"
    anywhere = "anywhere"
    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {self.name: self.value}
        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.value)

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, PatternRecognizerAnchorType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask_sdk_model-1.55.0-py2.py3-none-any.whl: ask_sdk_model/services/game_engine/pattern_recognizer_anchor_type.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union, Any
    from datetime import datetime


class PatternRecognizerAnchorType(Enum):
    """
    Where the pattern must appear in the history of this input handler. * &#x60;start&#x60; -  (Default) The first event in the pattern must be the first event in the history of raw Echo Button events. * &#x60;end&#x60; - The last event in the pattern must be the last event in the history of raw Echo Button events. * &#x60;anywhere&#x60; - The pattern may appear anywhere in the history of raw Echo Button events. 



    Allowed enum values: [start, end, anywhere]
    """
    start = "start"
    end = "end"
    anywhere = "anywhere"

    def to_dict(self):
        # type: () -> Dict[str, Any]
        """Returns the model properties as a dict"""
        result = {self.name: self.value}
        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.value)

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (Any) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, PatternRecognizerAnchorType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (Any) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
